@@ -4,7 +4,7 @@ from notion_client.helpers import get_id
 from notion2md.console import print_error
 
 class Config(object):
-    __slots__ = ("file_name", "target_id", "output_path")
+    __slots__ = ("file_name", "target_id", "output_path","download")
     def __init__(self,**kargs):
         if "url" in kargs and kargs['url']:
             self.target_id = get_id(kargs['url'])
@@ -24,6 +24,11 @@ class Config(object):
         else:
             self.output_path = os.path.join(os.getcwd(),'notion2md-output')
 
+        if "download" in kargs and kargs['download']:
+            self.download = True
+        else:
+            self.download = False
+
 config = None
 
 def set_config(**kargs):
